#!/bin/bash
#/////////////////////////////////////////////////////////////////////////
#//
#// (c) University of Southampton IT Innovation Centre, 2017
#//
#// Copyright in this software belongs to University of Southampton
#// IT Innovation Centre of Gamma House, Enterprise Road,
#// Chilworth Science Park, Southampton, SO16 7NS, UK.
#//
#// This software may not be used, sold, licensed, transferred, copied
#// or reproduced in whole or in part in any manner or form or in or
#// on any media by any person other than in accordance with the terms
#// of the Licence Agreement supplied with the software, or otherwise
#// without the prior written consent of the copyright owners.
#//
#// This software is distributed WITHOUT ANY WARRANTY, without even the
#// implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
#// PURPOSE, except where stated in the Licence Agreement supplied with
#// the software.
#//
#//      Created By :            Michael Boniface
#//      Created Date :          13/12/2017
#//      Created for Project :   FLAME
#//
#/////////////////////////////////////////////////////////////////////////

# Force fail on command fail
set -euo pipefail

echo "Configuring Telegraf agent general and output configuration"

# Get command line parameters
if [ "$#" -ne 10 ]; then
    echo "Error: illegal number of arguments: "$#
      echo "Usage: config.sh TELEGRAF_GENERAL_CONF_FILE TELEGRAF_OUTPUT_CONF_FILE LOCATION SFC_ID SFC_ID_INSTANCE SF_ID SF_ID_INSTANCE IP_ENDPOINT_ID INFLUXDB_URL DATABASE_NAME"
      exit 
fi

TELEGRAF_GENERAL_CONF_FILE=$1
TELEGRAF_OUTPUT_CONF_FILE=$2
LOCATION=$3
SFC_ID=$4
SFC_ID_INSTANCE=$5
SF_ID=$6
SF_ID_INSTANCE=$7
IP_ENDPOINT_ID=$8
INFLUXDB_URL=$9
DATABASE_NAME=${10}

TELEGRAF_CONF_DIR="/etc/telegraf"
TELEGRAF_CONF_FILE="$TELEGRAF_CONF_DIR/telegraf.conf"
TELEGRAF_INCLUDE_CONF_DIR="/etc/telegraf/telegraf.d"
TELEGRAF_OUTPUT_FILE="$TELEGRAF_INCLUDE_CONF_DIR/telegraf_output.conf"

echo "Checking Telegraf installation"

# Check the configuration files provided exist

echo "TELEGRAF_GENERAL_CONF_FILE: "$TELEGRAF_GENERAL_CONF_FILE
if [ ! -f $TELEGRAF_GENERAL_CONF_FILE ]; then
    echo "Error: Telegraf conf template file not found: "$TELEGRAF_GENERAL_CONF_FILE
    exit
fi

echo "TELEGRAF_OUTPUT_CONF_FILE: "$TELEGRAF_OUTPUT_CONF_FILE
if [ ! -f $TELEGRAF_OUTPUT_CONF_FILE ]; then
    echo "Error: Telegraf output conf specific file not found: "$TELEGRAF_OUTPUT_CONF_FILE
    exit
fi

# Check the target telegraf directory exists
if [ ! -d "$TELEGRAF_CONF_DIR" ]; then
    echo "Error: Telegraf conf directory does not exist on target machine. Check that telegraf is installed "$TELEGRAF_CONF_DIR
    exit
fi

# Check the target telegraf directory exists
if [ ! -d $TELEGRAF_INCLUDE_CONF_DIR ]; then
    echo "Error: Telegraf conf include directory does not exist on target machine. Check that telegraf is installed "$TELEGRAF_INCLUDE_CONF_DIR
    exit
fi

echo "Copying configuration"

# Copy configuration
echo "Telegraf general config file: " $TELEGRAF_GENERAL_CONF_FILE
cp $TELEGRAF_GENERAL_CONF_FILE $TELEGRAF_CONF_FILE

echo "Telegraf output config file: " $TELEGRAF_OUTPUT_CONF_FILE
cp $TELEGRAF_OUTPUT_CONF_FILE $TELEGRAF_OUTPUT_FILE

# Replace template parameters on general configuration
sed -i 's/$LOCATION/'$LOCATION'/g' $TELEGRAF_CONF_FILE
sed -i 's/$SFC_ID/'$SFC_ID'/g' $TELEGRAF_CONF_FILE
sed -i 's/$SFC_ID_INSTANCE/'$SFC_ID_INSTANCE'/g' $TELEGRAF_CONF_FILE
sed -i 's/$SF_ID/'$SF_ID'/g' /etc/telegraf/telegraf.conf
sed -i 's/$SF_ID_INSTANCE}}/'$SF_ID_INSTANCE'/g' $TELEGRAF_CONF_FILE
sed -i 's/$IP_ENDPOINT_ID/'$IP_ENDPOINT_ID'/g' $TELEGRAF_CONF_FILE

# Replace parameters on output configuration
echo "INFLUXDB_URL: " $INFLUXDB_URL
echo "DATABASE_NAME: " $DATABASE_NAME

sed -i 's|$INFLUXDB_URL|'$INFLUXDB_URL'|g' $TELEGRAF_OUTPUT_FILE
sed -i 's/$DATABASE_NAME/'$DATABASE_NAME'/g' $TELEGRAF_OUTPUT_FILE

# Start telegraf
systemctl restart telegraf
